aboutsummaryrefslogtreecommitdiffstats
path: root/embed/ephy-embed-container.c
diff options
context:
space:
mode:
authorXan Lopez <xan@gnome.org>2009-06-05 21:32:55 +0800
committerXan Lopez <xan@gnome.org>2009-06-05 22:54:08 +0800
commit8f3aa835aa3fb12e8f9805c3ecb454027398102c (patch)
tree94223e73426ef759ad4176c33ef3a659895eb0ac /embed/ephy-embed-container.c
parent1d49b43e4da3c5153a444596b24340d40ad98d31 (diff)
downloadgsoc2013-epiphany-8f3aa835aa3fb12e8f9805c3ecb454027398102c.tar
gsoc2013-epiphany-8f3aa835aa3fb12e8f9805c3ecb454027398102c.tar.gz
gsoc2013-epiphany-8f3aa835aa3fb12e8f9805c3ecb454027398102c.tar.bz2
gsoc2013-epiphany-8f3aa835aa3fb12e8f9805c3ecb454027398102c.tar.lz
gsoc2013-epiphany-8f3aa835aa3fb12e8f9805c3ecb454027398102c.tar.xz
gsoc2013-epiphany-8f3aa835aa3fb12e8f9805c3ecb454027398102c.tar.zst
gsoc2013-epiphany-8f3aa835aa3fb12e8f9805c3ecb454027398102c.zip
Move all methods, signals and properties from EphyEmbed and EphyBaseEmbed to EphyWebView.
Those two embed classes are pretty much dummy leftovers, so it should be easier to remove them now.
Diffstat (limited to 'embed/ephy-embed-container.c')
-rw-r--r--embed/ephy-embed-container.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/embed/ephy-embed-container.c b/embed/ephy-embed-container.c
index c2a6ad9cd..1a55eb66a 100644
--- a/embed/ephy-embed-container.c
+++ b/embed/ephy-embed-container.c
@@ -33,8 +33,8 @@ ephy_embed_container_base_init (gpointer g_class)
g_object_interface_install_property (g_class,
g_param_spec_flags ("chrome", NULL, NULL,
- EPHY_TYPE_EMBED_CHROME,
- EPHY_EMBED_CHROME_ALL,
+ EPHY_TYPE_WEB_VIEW_CHROME,
+ EPHY_WEB_VIEW_CHROME_ALL,
G_PARAM_CONSTRUCT_ONLY |
G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
@@ -205,12 +205,12 @@ ephy_embed_container_get_is_popup (EphyEmbedContainer *container)
* ephy_embed_container_get_chrome:
* @container: an #EphyEmbedContainer
*
* Returns the #EphyEmbedChrome flags indicating the visibility of several parts
* of the UI.
*
* Return value: #EphyEmbedChrome flags.
**/
-EphyEmbedChrome
+EphyWebViewChrome
ephy_embed_container_get_chrome (EphyEmbedContainer *container)
{
EphyEmbedContainerIface *iface;
@@ -205,12 +205,12 @@ ephy_embed_container_get_is_popup (EphyEmbedContainer *container)
* @container: an #EphyEmbedContainer
*
- * Returns the #EphyEmbedChrome flags indicating the visibility of several parts
+ * Returns the #EphyWebViewChrome flags indicating the visibility of several parts
* of the UI.
*
@@ -205,12 +205,12 @@ ephy_embed_container_get_is_popup (EphyEmbedContainer *container)
* of the UI.
*
- * Return value: #EphyEmbedChrome flags.
+ * Return value: #EphyWebViewChrome flags.
**/